@@ -768,7 +768,7 @@ rp.cor.plot <- function(x, lower.panel = 'panel.smooth', upper.panel = 'panel.co
             ## forked from ?pairs
             usr <- par("usr"); on.exit(par(usr))
             par(usr = c(0, 1, 0, 1))
-            r <- cor(x, y)
+            r <- cor(x, y, use = 'complete.obs')
             txt <- format(c(r, 0.123456789), digits = digits)[1]
             txt <- paste(prefix, txt, sep = "")
             if(missing(cex.cor)) cex <- 0.8/strwidth(txt)
